@@ -16,7 +16,10 @@ TOKEN = "xxxxxxxxxxxxx"
 async def test_hours_analytics() -> None:
     """Test analytics compute."""
     dataset = DS_30["meter_reading"]["interval_reading"]
-    cumsum = 1000
+    cumsums = {
+        "standard": {"sum_value": 1000, "sum_price": 0},
+        "offpeak": {"sum_value": 1000, "sum_price": 0},
+    }
     intervals = [("01:30:00", "08:00:00"), ("12:30:00", "14:00:00")]
     analytics = EnedisAnalytics(dataset)
     resultat = analytics.get_data_analytics(
@@ -26,10 +29,10 @@ async def test_hours_analytics() -> None:
         freq="H",
         groupby=True,
         summary=True,
-        cumsum=cumsum,
+        cumsums=cumsums,
         prices=(0.17, 0.18),
     )
-    assert resultat[0]["notes"] == "HC"
+    assert resultat[0]["notes"] == "offpeak"
     assert resultat[0]["value"] == 0.618
     assert resultat[0].get("sum_value") is not None
     assert resultat[0].get("sum_price") is not None
@@ -44,7 +47,7 @@ async def test_hours_analytics() -> None:
         groupby=True,
         prices=(0.17, 0.18),
     )
-    assert resultat[0]["notes"] == "HC"
+    assert resultat[0]["notes"] == "offpeak"
     assert resultat[0]["value"] == 0.618
     assert resultat[2]["price"] == 0.55152
     assert resultat[0].get("sum_value") is None
@@ -61,18 +64,6 @@ async def test_hours_analytics() -> None:
     )
     print(resultat)
 
-    analytics = EnedisAnalytics(dataset)
-    resultat = analytics.get_data_analytics(
-        convertKwh=True,
-        convertUTC=False,
-        intervals=intervals,
-        freq="30T",
-        groupby=True,
-    )
-    assert resultat[48]["notes"] == "HP"
-    assert resultat[48]["value"] == 0.672
-    print(resultat)
-
     analytics = EnedisAnalytics(dataset)
     resultat = analytics.get_data_analytics(
         convertKwh=True,
@@ -93,7 +84,7 @@ async def test_hours_analytics() -> None:
         freq="D",
         groupby=True,
         summary=True,
-        cumsum=cumsum,
+        cumsums=cumsums,
         prices=(0.17, 0.18),
     )
     assert resultat[0]["value"] == 33.951
@@ -104,7 +95,6 @@ async def test_hours_analytics() -> None:
 @pytest.mark.asyncio
 async def test_daily_analytics() -> None:
     dataset = DS_30["meter_reading"]["interval_reading"]
-    cumsum = 0
     intervals = [("01:30:00", "08:00:00"), ("12:30:00", "14:00:00")]
     dataset = DS_DAILY["meter_reading"]["interval_reading"]
     analytics = EnedisAnalytics(dataset)
@@ -115,7 +105,6 @@ async def test_daily_analytics() -> None:
         freq="D",
         groupby=True,
         summary=True,
-        cumsum=cumsum,
         prices=(0.17, 0.18),
     )
     assert resultat[359]["value"] == 68.68
@@ -124,7 +113,10 @@ async def test_daily_analytics() -> None:
 
 @pytest.mark.asyncio
 async def test_compare_analytics() -> None:
-    cumsum = 0
+    cumsums = {
+        "standard": {"sum_value": 0, "sum_price": 0},
+        "offpeak": {"sum_value": 0, "sum_price": 0},
+    }
     intervals = [("01:30:00", "08:00:00"), ("12:30:00", "14:00:00")]
     dataset = DS_30["meter_reading"]["interval_reading"]
     analytics = EnedisAnalytics(dataset)
@@ -135,7 +127,7 @@ async def test_compare_analytics() -> None:
         freq="D",
         groupby=True,
         summary=True,
-        cumsum=cumsum,
+        cumsums=cumsums,
         prices=(0.17, 0.18),
         start_date="2023-02-28",
     )
@@ -155,9 +147,37 @@ async def test_compare_analytics() -> None:
         freq="D",
         groupby=True,
         summary=True,
-        cumsum=cumsum,
+        cumsums=cumsums,
         prices=(0.17, 0.18),
         start_date="2023-02-28",
     )
     assert sum_value == resultat2[2]["sum_value"]
     print(resultat2)
+
+
+@pytest.mark.asyncio
+async def test_cumsums_analytics() -> None:
+    cumsums = {
+        "standard": {"sum_value": 100, "sum_price": 50},
+        "offpeak": {"sum_value": 1000, "sum_price": 75},
+    }
+    intervals = [("01:30:00", "08:00:00"), ("12:30:00", "14:00:00")]
+    dataset = DS_30["meter_reading"]["interval_reading"]
+    analytics = EnedisAnalytics(dataset)
+    resultat = analytics.get_data_analytics(
+        convertKwh=True,
+        convertUTC=False,
+        intervals=intervals,
+        freq="D",
+        groupby=True,
+        summary=True,
+        cumsums=cumsums,
+        prices=(0.17, 0.18),
+        start_date="2023-02-28",
+    )
+    # offpeak
+    assert resultat[0]["sum_value"] == resultat[0]["value"] + 1000
+    assert resultat[0]["sum_price"] == resultat[0]["price"] + 75
+    # standard
+    assert resultat[3]["sum_value"] == resultat[3]["value"] + 100
+    assert resultat[3]["sum_price"] == resultat[3]["price"] + 50
